:mod:`kwant.physics` -- Physics-related algorithms
==================================================

.. module:: kwant.physics

Leads
-----
.. autosummary::
   :toctree: generated/

   Bands
   modes
   selfenergy
   two_terminal_shotnoise
   PropagatingModes
   StabilizedModes
